@@ -4,7 +4,7 @@
 #' the distribution family specified in the \code{"family"} parameter.
 #' @author Ines Ortega-Fernandez, Marta Sestelo.
 #' @param family A description of the link function used in the model:
-#' \code{"gaussian"} or \code{"binomial"}
+#' \code{"gaussian"}, \code{"poisson"}, or \code{"binomial"}
 #' @param muhat fitted values
 #' @return derivative of the link function for the fitted values
 #' @keywords internal
@@ -18,8 +18,8 @@ diriv <- function(family, muhat) {
     stop("Argument \"family\" is missing, with no default")
   }
 
-  if (family != "gaussian" & family != "binomial"){
-    stop("Unsupported distribution family. Supported values are \"gaussian\" and \"binomial\"")
+  if (!family %in% c("gaussian", "binomial", "poisson")) {
+    stop("Unsupported distribution family. Supported values are \"gaussian\", \"binomial\", and \"poisson\"")
   }
 
   if (family == "gaussian") { # Identity
@@ -32,5 +32,8 @@ diriv <- function(family, muhat) {
     prob <- prob * (1.0 - prob)
     out <- 1.0 / prob
   }
+  if(family == "poisson") {
+    out <- 1 / pmax(muhat, 1e-4)
+  }
   return(out)
 }
