@@ -4,10 +4,11 @@
 #' specified in the \code{"family"} parameter.
 #' @author Ines Ortega-Fernandez, Marta Sestelo.
 #' @param family A description of the link function used in the model:
-#' \code{"gaussian"} or \code{"binomial"}
+#' \code{"gaussian"}, \code{"poisson"}, or \code{"binomial"}
 #' @param muhat fitted values
 #' @return the link function specified by the \code{"family"} distribution
 #' for the given fitted values
+#' @author Ines Ortega-Fernandez, Marta Sestelo
 #' @keywords internal
 
 link <- function(family, muhat) {
@@ -20,18 +21,23 @@ link <- function(family, muhat) {
     stop("Argument \"family\" is missing, with no default")
   }
 
-  if (family != "gaussian" & family != "binomial") {
-    stop("Unsupported distribution family. Supported values are \"gaussian\" and \"binomial\"")
+  if (!family %in% c("gaussian", "binomial", "poisson")) {
+    stop("Unsupported distribution family. Supported values are \"gaussian\", \"binomial\", and \"poisson\"")
   }
 
-
   if (family == "gaussian") {
     out <- muhat
   }
   if (family == "binomial") {
-    muhat[muhat > 10] <- 10
-    muhat[muhat < -10] <- -10
-    out <- exp(muhat) / (1 + exp(muhat))
+    d <- pmax(1 - muhat, 1e-4)
+    ratio <- muhat / d
+    ratio <- pmin(pmax(ratio, 1e-4), 9999.0)
+    out <- log(ratio)
   }
+  if (family == "poisson") {
+    muhat <- pmax(muhat, 1e-4)
+    out <- log(muhat)
+  }
+
   return(out)
 }
